# honeybee_ph_standards
Additional standards which are useful to Passive House practitioners.

![image](https://user-images.githubusercontent.com/69652712/169719406-2152296c-4cb4-4e15-b566-fb25b3bdfd24.png)
